==> skypager-project-2.60.1.tgz: package/lib/framework.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _values = require('babel-runtime/core-js/object/values');

var _values2 = _interopRequireDefault(_values);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _collection = require('./collection');

var _collection2 = _interopRequireDefault(_collection);

var _registry = require('./registry');

var _registry2 = _interopRequireDefault(_registry);

var _project = require('./project');

var _project2 = _interopRequireDefault(_project);

var _util = require('./util');

var util = _interopRequireWildcard(_util);

var _assets = require('./assets');

var Assets = _interopRequireWildcard(_assets);

var _helpers = require('./helpers');

var Helpers = _interopRequireWildcard(_helpers);

var _path = require('path');

var _defaultsDeep = require('lodash/defaultsDeep');

var _defaultsDeep2 = _interopRequireDefault(_defaultsDeep);

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _isEmpty = require('lodash/isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

var _pathExists = require('path-exists');

var _pathExists2 = _interopRequireDefault(_pathExists);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

GLOBAL.invariant = require('invariant');

// temp
//if (!process.env.SKYPAGER_DIST) { require('./environment')() }

delete Assets.default;
delete Helpers.default;
delete _project2.default.default;

var ProjectCache = {
  projects: {}
};

var pkg = require('../package.json');

var Framework = (function () {
  function Framework() {
    var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var initializer = arguments[1];
    (0, _classCallCheck3.default)(this, Framework);

    options = (0, _defaultsDeep2.default)(options, {
      type: 'framework',
      key: 'skypager',
      transforms: [],
      root: __dirname
    });

    this.root = options.root;
    this.type = options.type;
    this.key = options.key;

    util.hide.property(this, 'createStamp', Math.floor(Date.now() / 100));
    util.hide.property(this, 'registryId', this.key + '-' + this.type + ':' + this.createStamp);

    //util.hide.getter(this, 'manifest', require('../package.json'))

    this.registries = _registry2.default.buildAll(this, Helpers, { root: root });

    this.transforms = [];

    util.hide.property(this, 'enabledPlugins', []);
    util.hide.property(this, '_loadedPlugins', []);

    this.discoverPlugins();

    if (typeof initializer === 'function') {
      initializer(this);
    }

    //require('./environment')(this.root)
  }

  (0, _createClass3.default)(Framework, [{
    key: 'discoverPlugins',
    value: function discoverPlugins() {

      if (!_pathExists2.default.sync((0, _path.join)(process.env.PWD, 'package.json'))) {
        return;
      }

      var projectManifest = require((0, _path.join)(process.env.PWD, 'package.json'));
      var pluginIds = [];

      if (projectManifest) {
        pluginIds = pluginIds.concat((0, _get2.default)(projectManifest, 'skypager.plugins') || []);
      }

      if (this.key !== 'skypager') {
        pluginIds = pluginIds.concat((0, _get2.default)(projectManifest, this.key + '.plugins') || []);
      }

      eagerLoadProjectPlugins(this, pluginIds);

      // this will search nodes require paths for plugins
      // holding off for now
      //eagerLoadFoundPlugins(this)
    }
  }, {
    key: 'clearProjectCache',
    value: function clearProjectCache() {
      this.projectCacheKeys.forEach(function (key) {
        return delete ProjectCache.projects[key];
      });
    }
    /**
    * Create a project loader for the specified path.
    * Returns a function you can execute when you want the project loaded.
    */

  }, {
    key: 'create',
    value: function create(pathToProject) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      var skypager = this;

      return function () {
        var opts = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

        return new skypager.load(pathToProject, (0, _assign2.default)(options, opts));
      };
    }
  }, {
    key: 'maybeBabel',
    value: function maybeBabel() {
      var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

      try {
        require('babel-polyfill');
      } catch (error) {}

      if (!this.isBabelRegistered) {
        try {
          require('babel-register')({ presets: ['skypager'] });
        } catch (error) {
          console.log('There was an error trying to babel-register', error);
          return this.babelRegistered = false;
        }
      }

      return this.babelRegistered = true;
    }

    /**
    * Load a project in the specified path immediately.
    *
    */

  }, {
    key: 'load',
    value: function load() {
      var _this = this;

      var projectFile = arguments.length <= 0 || arguments[0] === undefined ? process.env.PWD : arguments[0];
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      var skypager = this;

      skypager.maybeBabel();

      if ((typeof projectFile === 'undefined' ? 'undefined' : (0, _typeof3.default)(projectFile)) === 'object') {
        if ((0, _isEmpty2.default)(options)) {
          options = projectFile;
        }

        projectFile = options.root || process.env.PWD;
      }

      if (!options.fresh && ProjectCache.projects[projectFile]) {
        return ProjectCache.projects[projectFile];
      }

      var root = projectFile;

      if (projectFile.match(/\.(js|json)$/i)) {
        root = (0, _path.dirname)(projectFile);
      }

      if (!options.manifest) {
        try {
          options.manifest = require((0, _path.join)(root, 'package.json'));
        } catch (error) {
          console.log('Error loading manifest', error.message, (0, _path.join)(root, 'package.json'));
        }
      }

      (0, _defaultsDeep2.default)(options, {
        manifest: {
          skypager: {
            plugins: []
          }
        }
      }, (0, _defineProperty3.default)({}, this.key, {
        plugins: []
      }));

      var project = new this.Project(projectFile, options);

      util.hide.getter(project, '_framework', function () {
        return _this;
      });

      var transforms = this.transforms.filter(function (t) {
        return typeof t === 'function';
      });

      transforms.forEach(function (transform) {
        return transform(project, _this);
      });

      return ProjectCache.projects[projectFile] = this.wrap(project);
    }
  }, {
    key: 'wrap',
    value: function wrap(project) {
      return project;
    }
  }, {
    key: 'use',
    value: function use(plugins) {
      var _this2 = this;

      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      if (typeof plugins === 'string') {
        plugins = [plugins];
      }

      plugins.forEach(function (plugin) {
        var pluginConfig = _this2.plugins.lookup(plugin);

        if (pluginConfig && pluginConfig.api && pluginConfig.api.modify) {
          pluginConfig.api.modify(_this2);
        } else {
          if (pluginConfig && typeof pluginConfig.api === 'function') {
            pluginConfig.api.call(_this2, _this2, pluginConfig);
          }
        }

        _this2.enabledPlugins.push(plugin);
      });
    }

    /**
     * Load a plugin by name, or by passing the plugins loader function
     *
     * @param {String||Function} moduleId a required plugin or a requireable path to that plugin
     *  will attempt to find the plugin by attaching the skypager-plugin- prefix as well.
    */

  }, {
    key: 'loadPlugin',
    value: function loadPlugin(request) {
      var loader = undefined;

      if (typeof request === 'string') {
        loader = attemptRequires(request, 'skypager-plugin-' + request, this.key + '-plugin-' + request);
      }

      /*
      if(this._loadedPlugins.indexOf((loader || request).name) >= 0) {
        return
      }
      */

      try {
        this.plugins.runLoader(loader || request);
        //this._loadedPlugins.push((loader || request).name)
        return true;
      } catch (error) {
        return false;
      }
    }
  }, {
    key: 'version',
    get: function get() {
      return this.constructor.Version;
    }
  }, {
    key: 'moduleName',
    get: function get() {
      return this.constructor.Name;
    }
  }, {
    key: 'isNodeModule',
    get: function get() {
      return (0, _path.basename)(this.moduleRoot) === 'node_modules';
    }
  }, {
    key: 'isLocalPackage',
    get: function get() {
      return (0, _path.basename)(this.moduleRoot) === 'packages';
    }
  }, {
    key: 'isCompiled',
    get: function get() {
      return (0, _path.basename)(this.root) === 'lib';
    }
  }, {
    key: 'moduleRoot',
    get: function get() {
      return (0, _path.dirname)((0, _path.join)(this.root, '..'));
    }
  }, {
    key: 'peerModules',
    get: function get() {
      var _this3 = this;

      return require('fs').readdirSync(this.moduleRoot).filter(function (name) {
        return name && name.match(_this3.key);
      });
    }
  }, {
    key: 'allProjects',
    get: function get() {
      return (0, _values2.default)(ProjectCache.projects);
    }
  }, {
    key: 'projectCacheKeys',
    get: function get() {
      return (0, _keys2.default)(ProjectCache.projects);
    }
  }, {
    key: 'isBabelRegistered',
    get: function get() {
      if (this.babelRegistered) {
        return true;
      }

      if (require.extensions && require.extensions['.es6']) {
        return true;
      }
    }
  }, {
    key: 'loadedProjects',
    get: function get() {
      return (0, _values2.default)(ProjectCache.projects);
    }
  }, {
    key: 'actions',
    get: function get() {
      return this.registries.actions;
    }
  }, {
    key: 'contexts',
    get: function get() {
      return this.registries.contexts;
    }
  }, {
    key: 'exporters',
    get: function get() {
      return this.registries.exporters;
    }
  }, {
    key: 'importers',
    get: function get() {
      return this.registries.importers;
    }
  }, {
    key: 'models',
    get: function get() {
      return this.registries.models;
    }
  }, {
    key: 'plugins',
    get: function get() {
      return this.registries.plugins;
    }
  }, {
    key: 'renderers',
    get: function get() {
      return this.registries.renderers;
    }
  }, {
    key: 'util',
    get: function get() {
      return util;
    }
  }]);
  return Framework;
})();

Framework.Version = pkg.version;
Framework.Name = pkg.name;

function eagerLoadProjectPlugins(framework, list) {
  var requestedPlugins = list.filter(function (item) {
    return typeof item === 'string' && item.length > 0;
  });

  requestedPlugins.map(function (request) {
    return util.findPackageSync(request) || request;
  }).map(function (request) {
    return attemptRequires(request, 'skypager-plugin-' + request, framework.key + '-plugin-' + request);
  }).map(function (foundPlugin) {
    return foundPlugin && attemptRequire(foundPlugin);
  }).map(function (loader) {
    return loader && loader.default ? loader.default : loader;
  }).filter(function (loader) {
    return typeof loader === 'function';
  }).map(function (loader) {
    return framework.loadPlugin(loader);
  }).filter(function (result) {
    return !!result;
  });
}

function eagerLoadFoundPlugins(framework) {
  var checkFolders = [];

  try {
    checkFolders = require.cache[module.id].paths;
  } catch (error) {
    checkFolders = [];
  }

  checkFolders = checkFolders.filter(function (dir) {
    return _pathExists2.default.sync(dir);
  });

  if (framework.key !== 'skypager') {
    checkFolders.forEach(function (moduleFolder) {
      getModulesMatchingPrefix(moduleFolder, 'skypager-plugin');
    });
  }

  checkFolders.forEach(function (moduleFolder) {
    getModulesMatchingPrefix(moduleFolder, framework.key + '-plugin').forEach(function (plugin) {
      return framework.loadPlugin(plugin);
    });
  });
}

function attemptRequires() {
  try {
    for (var _len = arguments.length, guesses = Array(_len), _key = 0; _key < _len; _key++) {
      guesses[_key] = arguments[_key];
    }

    return guesses.unique().find(attemptRequire);
  } catch (error) {}
}

function attemptRequire(moduleId) {
  try {
    return require(moduleId);
  } catch (error) {}
}

function getModulesMatchingPrefix(dir, prefix) {
  var fs = require('fs');
  var path = require('path');
  var dirs = [];
  var files = fs.readdirSync(dir);

  files.forEach(function (file) {
    var fullPath = path.join(dir, file);
    var stat = fs.statSync(fullPath);
    if (stat.isDirectory() && file.startsWith(prefix)) {
      dirs.push(file);
    }
  });

  return dirs;
}

module.exports = Framework;

==> skypager-project-2.70.6.tgz: package/lib/framework.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _values = require('babel-runtime/core-js/object/values');

var _values2 = _interopRequireDefault(_values);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _class, _temp; //if (!process.env.SKYPAGER_DIST) { require('./environment')() }

var _collection = require('./collection');

var _collection2 = _interopRequireDefault(_collection);

var _registry = require('./registry');

var _registry2 = _interopRequireDefault(_registry);

var _project = require('./project');

var _project2 = _interopRequireDefault(_project);

var _util = require('./util');

var util = _interopRequireWildcard(_util);

var _assets = require('./assets');

var Assets = _interopRequireWildcard(_assets);

var _helpers = require('./helpers');

var Helpers = _interopRequireWildcard(_helpers);

var _path = require('path');

var _defaultsDeep = require('lodash/defaultsDeep');

var _defaultsDeep2 = _interopRequireDefault(_defaultsDeep);

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _isEmpty = require('lodash/isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

var _pathExists = require('path-exists');

var _pathExists2 = _interopRequireDefault(_pathExists);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

GLOBAL.invariant = require('invariant');

// temp
delete Assets.default;
delete Helpers.default;
delete _project2.default.default;

var ProjectCache = {
  projects: {}
};

var pkg = require('../package.json');

var Framework = (_temp = _class = (function () {
  function Framework() {
    var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    var initializer = arguments[1];
    (0, _classCallCheck3.default)(this, Framework);

    options = (0, _defaultsDeep2.default)(options, {
      type: 'framework',
      key: 'skypager',
      transforms: [],
      root: __dirname
    });

    this.root = options.root;
    this.type = options.type;
    this.key = options.key;

    util.hide.property(this, 'createStamp', Math.floor(Date.now() / 100));
    util.hide.property(this, 'registryId', this.key + '-' + this.type + ':' + this.createStamp);

    //util.hide.getter(this, 'manifest', require('../package.json'))

    this.registries = _registry2.default.buildAll(this, Helpers, { root: root });

    this.transforms = [];

    util.hide.property(this, 'enabledPlugins', []);
    util.hide.property(this, '_loadedPlugins', []);

    this.discoverPlugins();

    if (typeof initializer === 'function') {
      initializer(this);
    }

    //require('./environment')(this.root)
  }

  (0, _createClass3.default)(Framework, [{
    key: 'discoverPlugins',
    value: function discoverPlugins() {

      if (!_pathExists2.default.sync((0, _path.join)(process.env.PWD, 'package.json'))) {
        return;
      }

      var projectManifest = require((0, _path.join)(process.env.PWD, 'package.json'));
      var pluginIds = [];

      if (projectManifest) {
        pluginIds = pluginIds.concat((0, _get2.default)(projectManifest, 'skypager.plugins') || []);
      }

      if (this.key !== 'skypager') {
        pluginIds = pluginIds.concat((0, _get2.default)(projectManifest, this.key + '.plugins') || []);
      }

      eagerLoadProjectPlugins(this, pluginIds);

      // this will search nodes require paths for plugins
      // holding off for now
      //eagerLoadFoundPlugins(this)
    }
  }, {
    key: 'clearProjectCache',
    value: function clearProjectCache() {
      this.projectCacheKeys.forEach(function (key) {
        return delete ProjectCache.projects[key];
      });
    }
    /**
    * Create a project loader for the specified path.
    * Returns a function you can execute when you want the project loaded.
    */

  }, {
    key: 'create',
    value: function create(pathToProject) {
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      var skypager = this;

      return function () {
        var opts = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

        return new skypager.load(pathToProject, (0, _assign2.default)(options, opts));
      };
    }
  }, {
    key: 'maybeBabel',
    value: function maybeBabel() {
      var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

      try {
        require('babel-polyfill');
      } catch (error) {}

      if (!this.isBabelRegistered) {
        try {
          require('babel-register')({ presets: ['skypager'] });
        } catch (error) {
          console.log('There was an error trying to babel-register', error);
          return this.babelRegistered = false;
        }
      }

      return this.babelRegistered = true;
    }

    /**
    * Load a project in the specified path immediately.
    *
    */

  }, {
    key: 'load',
    value: function load() {
      var _this = this;

      var projectFile = arguments.length <= 0 || arguments[0] === undefined ? process.env.PWD : arguments[0];
      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      var skypager = this;

      skypager.maybeBabel();

      if ((typeof projectFile === 'undefined' ? 'undefined' : (0, _typeof3.default)(projectFile)) === 'object') {
        if ((0, _isEmpty2.default)(options)) {
          options = projectFile;
        }

        projectFile = options.root || process.env.PWD;
      }

      if (!options.fresh && ProjectCache.projects[projectFile]) {
        return ProjectCache.projects[projectFile];
      }

      var root = projectFile;

      if (projectFile.match(/\.(js|json)$/i)) {
        root = (0, _path.dirname)(projectFile);
      }

      if (!options.manifest) {
        try {
          options.manifest = require((0, _path.join)(root, 'package.json'));
        } catch (error) {
          console.log('Error loading manifest', error.message, (0, _path.join)(root, 'package.json'));
        }
      }

      (0, _defaultsDeep2.default)(options, {
        manifest: {
          skypager: {
            plugins: []
          }
        }
      }, (0, _defineProperty3.default)({}, this.key, {
        plugins: []
      }));

      var project = new this.Project(projectFile, options);

      util.hide.getter(project, '_framework', function () {
        return _this;
      });

      var transforms = this.transforms.filter(function (t) {
        return typeof t === 'function';
      });

      transforms.forEach(function (transform) {
        return transform(project, _this);
      });

      return ProjectCache.projects[projectFile] = this.wrap(project);
    }
  }, {
    key: 'wrap',
    value: function wrap(project) {
      return project;
    }
  }, {
    key: 'use',
    value: function use(plugins) {
      var _this2 = this;

      var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      if (typeof plugins === 'string') {
        plugins = [plugins];
      }

      plugins.forEach(function (plugin) {
        var pluginConfig = _this2.plugins.lookup(plugin);

        if (pluginConfig && pluginConfig.api && pluginConfig.api.modify) {
          pluginConfig.api.modify(_this2);
        } else {
          if (pluginConfig && typeof pluginConfig.api === 'function') {
            pluginConfig.api.call(_this2, _this2, pluginConfig);
          }
        }

        _this2.enabledPlugins.push(plugin);
      });
    }

    /**
     * Load a plugin by name, or by passing the plugins loader function
     *
     * @param {String||Function} moduleId a required plugin or a requireable path to that plugin
     *  will attempt to find the plugin by attaching the skypager-plugin- prefix as well.
    */

  }, {
    key: 'loadPlugin',
    value: function loadPlugin(request) {
      var loader = undefined;

      if (typeof request === 'string') {
        loader = attemptRequires(request, 'skypager-plugin-' + request, this.key + '-plugin-' + request);
      }

      /*
      if(this._loadedPlugins.indexOf((loader || request).name) >= 0) {
        return
      }
      */

      try {
        this.plugins.runLoader(loader || request);
        //this._loadedPlugins.push((loader || request).name)
        return true;
      } catch (error) {
        return false;
      }
    }
  }, {
    key: 'version',
    get: function get() {
      return this.constructor.Version;
    }
  }, {
    key: 'moduleName',
    get: function get() {
      return this.constructor.Name;
    }
  }, {
    key: 'isNodeModule',
    get: function get() {
      return (0, _path.basename)(this.moduleRoot) === 'node_modules';
    }
  }, {
    key: 'isLocalPackage',
    get: function get() {
      return (0, _path.basename)(this.moduleRoot) === 'packages';
    }
  }, {
    key: 'isCompiled',
    get: function get() {
      return (0, _path.basename)(this.root) === 'lib';
    }
  }, {
    key: 'moduleRoot',
    get: function get() {
      return (0, _path.dirname)((0, _path.join)(this.root, '..'));
    }
  }, {
    key: 'peerModules',
    get: function get() {
      var _this3 = this;

      return require('fs').readdirSync(this.moduleRoot).filter(function (name) {
        return name && name.match(_this3.key);
      });
    }
  }, {
    key: 'allProjects',
    get: function get() {
      return (0, _values2.default)(ProjectCache.projects);
    }
  }, {
    key: 'projectCacheKeys',
    get: function get() {
      return (0, _keys2.default)(ProjectCache.projects);
    }
  }, {
    key: 'isBabelRegistered',
    get: function get() {
      if (this.babelRegistered) {
        return true;
      }

      if (require.extensions && require.extensions['.es6']) {
        return true;
      }
    }
  }, {
    key: 'loadedProjects',
    get: function get() {
      return (0, _values2.default)(ProjectCache.projects);
    }
  }, {
    key: 'actions',
    get: function get() {
      return this.registries.actions;
    }
  }, {
    key: 'contexts',
    get: function get() {
      return this.registries.contexts;
    }
  }, {
    key: 'exporters',
    get: function get() {
      return this.registries.exporters;
    }
  }, {
    key: 'importers',
    get: function get() {
      return this.registries.importers;
    }
  }, {
    key: 'models',
    get: function get() {
      return this.registries.models;
    }
  }, {
    key: 'plugins',
    get: function get() {
      return this.registries.plugins;
    }
  }, {
    key: 'renderers',
    get: function get() {
      return this.registries.renderers;
    }
  }, {
    key: 'util',
    get: function get() {
      return util;
    }
  }]);
  return Framework;
})(), _class.Version = pkg.version, _class.Name = pkg.name, _temp);

function eagerLoadProjectPlugins(framework, list) {
  var requestedPlugins = list.filter(function (item) {
    return typeof item === 'string' && item.length > 0;
  });

  requestedPlugins.map(function (request) {
    return util.findPackageSync(request) || request;
  }).map(function (request) {
    return attemptRequires(request, 'skypager-plugin-' + request, framework.key + '-plugin-' + request);
  }).map(function (foundPlugin) {
    return foundPlugin && attemptRequire(foundPlugin);
  }).map(function (loader) {
    return loader && loader.default ? loader.default : loader;
  }).filter(function (loader) {
    return typeof loader === 'function';
  }).map(function (loader) {
    return framework.loadPlugin(loader);
  }).filter(function (result) {
    return !!result;
  });
}

function eagerLoadFoundPlugins(framework) {
  var checkFolders = [];

  try {
    checkFolders = require.cache[module.id].paths;
  } catch (error) {
    checkFolders = [];
  }

  checkFolders = checkFolders.filter(function (dir) {
    return _pathExists2.default.sync(dir);
  });

  if (framework.key !== 'skypager') {
    checkFolders.forEach(function (moduleFolder) {
      getModulesMatchingPrefix(moduleFolder, 'skypager-plugin');
    });
  }

  checkFolders.forEach(function (moduleFolder) {
    getModulesMatchingPrefix(moduleFolder, framework.key + '-plugin').forEach(function (plugin) {
      return framework.loadPlugin(plugin);
    });
  });
}

function attemptRequires() {
  try {
    for (var _len = arguments.length, guesses = Array(_len), _key = 0; _key < _len; _key++) {
      guesses[_key] = arguments[_key];
    }

    return guesses.unique().find(attemptRequire);
  } catch (error) {}
}

function attemptRequire(moduleId) {
  try {
    return require(moduleId);
  } catch (error) {}
}

function getModulesMatchingPrefix(dir, prefix) {
  var fs = require('fs');
  var path = require('path');
  var dirs = [];
  var files = fs.readdirSync(dir);

  files.forEach(function (file) {
    var fullPath = path.join(dir, file);
    var stat = fs.statSync(fullPath);
    if (stat.isDirectory() && file.startsWith(prefix)) {
      dirs.push(file);
    }
  });

  return dirs;
}

module.exports = Framework;
